@@ -15,7 +15,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#define _GNU_SOURCE
+#include <config.h>
 
 #include <dirent.h>
 #include <errno.h>
@@ -87,7 +87,7 @@ typedef struct {
     const _action_t action;
 } _command_t;
 
-static const _command_t const commands[] = {
+static const _command_t commands[] = {
     { "scan", ldm_scan },
     { "show", ldm_show },
     { "create", ldm_create },
@@ -300,8 +300,10 @@ show_volume(LDM *const ldm, const gint argc, gchar ** const argv,
             json_builder_add_int_value(jb, size);
             json_builder_set_member_name(jb, "chunk-size");
             json_builder_add_int_value(jb, chunk_size);
-            json_builder_set_member_name(jb, "hint");
-            json_builder_add_string_value(jb, hint);
+            if (hint != NULL) {
+                json_builder_set_member_name(jb, "hint");
+                json_builder_add_string_value(jb, hint);
+            }
 
             json_builder_set_member_name(jb, "partitions");
             json_builder_begin_array(jb);
@@ -624,7 +626,7 @@ shell(LDM * const ldm, gchar ** const devices,
         history_len++;
         free(line);
 
-        gboolean result;
+        gboolean result = FALSE;
         if (!do_command(ldm, argc, argv, &result, out, jg, jb)) {
             if (g_strcmp0("quit", argv[0]) == 0 ||
                 g_strcmp0("exit", argv[0]) == 0)
@@ -777,7 +779,9 @@ main(int argc, char *argv[])
     }
     g_option_context_free(context);
 
+#if !GLIB_CHECK_VERSION(2,35,0)
     g_type_init();
+#endif
 
     LDM * const ldm = ldm_new(&err);
 
